<?php

/**
 * The file that defines actions on plugin activation.
 *
 * @package OrderProtectionWp
 */

declare(strict_types=1);

namespace OrderProtectionWp;

use OrderProtectionWpVendor\EightshiftLibs\Exception\PluginActivationFailure;
use OrderProtectionWpVendor\EightshiftLibs\Plugin\HasActivationInterface;

use const ABSPATH;

/**
 * The plugin activation class.
 *
 * @since 1.0.0
 */
class Activate implements HasActivationInterface
{
	/**
	 * Activate the plugin.
	 *
	 * @throws PluginActivationFailure Exception in the case PHP version is too low,
	 *                                 or WooCommerce isn't activated.
	 *
	 * @since 1.0.0
	 */
	public function activate(): void
	{
		if (!function_exists('is_plugin_active_for_network')) {
			include ABSPATH . '/wp-admin/includes/plugin.php';
		}

		if (version_compare((string)PHP_VERSION_ID, '70400', '<')) {
			deactivate_plugins(plugin_basename(__FILE__));

			$errorMessage = esc_html__('This plugin requires PHP 7.4 or greater to function.', 'orderprotection-wp');

			throw PluginActivationFailure::activationMessage($errorMessage);
		}

		if (!class_exists('WooCommerce')) {
			// Deactivate the plugin.
			deactivate_plugins(plugin_basename(__FILE__));

			$errorMessage = esc_html__('This plugin requires WooCommerce plugin to be active.', 'orderprotection-wp');

			throw PluginActivationFailure::activationMessage($errorMessage);
		}

		\flush_rewrite_rules();
	}
}
