<?php

/**
 * File holding PluginSettingsLink class
 *
 * @package OrderProtectionWp\Admin
 */

declare(strict_types=1);

namespace OrderProtectionWp\Admin;

use OrderProtectionWpVendor\EightshiftLibs\Services\ServiceInterface;

use function add_filter;
use function esc_html__;

/**
 * Adds action link to the plugin in the plugin screen
 *
 * @since 1.0.0
 */
class PluginSettingsLink implements ServiceInterface
{
	public const PLUGIN_LINK_HOOK = 'plugin_action_links_orderprotection/orderprotection.php';

	/**
	 * Register all the hooks.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public function register(): void
	{
		add_filter(self::PLUGIN_LINK_HOOK, [$this, 'addActionLink']);
	}

	/**
	 * Add plugin settings link on plugins page
	 *
	 * @param array<string, string> $links Plugin action links.
	 *
	 * @return array<string, string> Updated links that will be shown on the plugins install page.
	 */
	public function addActionLink(array $links): array
	{
		$link = sprintf(
			'<a href=\'%1$s\'>%2$s</a>',
			esc_url(admin_url('admin.php?page=wc-settings&tab=orderprotection')),
			esc_html__('Settings', 'orderprotection-wp')
		);
		$links['OrderProtectionSettings'] = $link;

		return $links;
	}
}
