<?php

/**
 * Abstract Ajax class file
 *
 * @package OrderProtectionWp\Ajax
 */

declare(strict_types=1);

namespace OrderProtectionWp\Ajax;

use OrderProtectionWpVendor\EightshiftLibs\Services\ServiceInterface;

/**
 * AbstractAjax class.
 *
 * @since 1.0.0
 *
 * AJAX implementation abstraction
 */
abstract class AbstractAjax implements ServiceInterface, AjaxInterface
{
	public const AJAX_CALLBACK_HANDLER = '';
	public const AJAX_PRIORITY = 10;
	public const IS_PRIVATE = true;

	/**
	 * Register all the hooks.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public function register(): void
	{
		$ajaxHandler = $this->getAjaxHandler();

		add_action("wp_ajax_$ajaxHandler", [$this, 'getAjaxCallback'], $this->getPriority());

		if (!$this->isPrivate()) {
			add_action("wp_ajax_nopriv_$ajaxHandler", [$this, 'getAjaxCallback'], $this->getPriority());
		}
	}

	/**
	 * Callback method for Ajax handler.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	abstract public function getAjaxCallback(): void;

	/**
	 * Ajax handler name getter.
	 *
	 * @since 1.0.0
	 *
	 * @return string
	 */
	protected function getAjaxHandler(): string
	{
		return static::AJAX_CALLBACK_HANDLER;
	}

	/**
	 * Hook priority getter.
	 *
	 * @since 1.0.0
	 *
	 * @return int
	 */
	private function getPriority(): int
	{
		return static::AJAX_PRIORITY;
	}

	/**
	 * Set the callback privacy.
	 * By default, the callback will only be executed for authenticated users.
	 *
	 * @since 1.0.0
	 *
	 * @return bool
	 */
	private function isPrivate(): bool
	{
		return static::IS_PRIVATE;
	}
}
