<?php

declare(strict_types=1);

namespace OrderProtectionWp\Api\Dto;

class OrderCreateDto
{
    /** @var string */
    private $sourceOrderId;

    /** @var string */
    private $sourceOrderNumber;

    /** @var string */
    private $sourceCreatedAt;

    /** @var string */
    private $sourceUpdatedAt;

    /** @var string */
    private $platformId;

    /** @var float */
    private $premiumPaid;

    /** @var string */
    private $currency;

    /** @var float */
    private $total;

    /** @var float */
    private $discountTotal;

    /** @var float */
    private $shippingCost;

    /** @var float */
    private $tax;

    /** @var float */
    private $subtotal;

    /** @var string */
    private $customerEmail;

    /** @var string */
    private $customerName;

    /** @var string */
    private $customerPhone;

    /** @var OrderItemDto[] */
    private $orderItems;

    /** @var AddressDto[] */
    private $addresses;


    /** @var string|null */
    private $originalSourceOrderNumber;

    public function __construct(
        $sourceOrderId,
        $sourceOrderNumber,
        $sourceCreatedAt,
        $sourceUpdatedAt,
        $platformId,
        $premiumPaid,
        $currency,
        $total,
        $discountTotal,
        $shippingCost,
        $tax,
        $subtotal,
        $customerEmail,
        $customerName,
        $customerPhone,
        array $orderItems,
        array $addresses,
        $originalSourceOrderNumber = null
    ) {
        $this->sourceOrderId = $sourceOrderId;
        $this->sourceOrderNumber = $sourceOrderNumber;
        $this->sourceCreatedAt = $sourceCreatedAt;
        $this->sourceUpdatedAt = $sourceUpdatedAt;
        $this->platformId = $platformId;
        $this->premiumPaid = $premiumPaid;
        $this->currency = $currency;
        $this->total = $total;
        $this->discountTotal = $discountTotal;
        $this->shippingCost = $shippingCost;
        $this->tax = $tax;
        $this->subtotal = $subtotal;
        $this->customerEmail = $customerEmail;
        $this->customerName = $customerName;
        $this->customerPhone = $customerPhone;
        $this->orderItems = $orderItems;
        $this->addresses = $addresses;
        $this->originalSourceOrderNumber = $originalSourceOrderNumber;
    }

    public function toArray(): array
    {
        return [
            'sourceOrderId' => $this->sourceOrderId,
            'sourceOrderNumber' => $this->sourceOrderNumber,
            'sourceCreatedAt' => $this->sourceCreatedAt,
            'sourceUpdatedAt' => $this->sourceUpdatedAt,
            'platformId' => $this->platformId,
            'premiumPaid' => $this->premiumPaid,
            'currency' => $this->currency,
            'total' => $this->total,
            'discountTotal' => $this->discountTotal,
            'shippingCost' => $this->shippingCost,
            'tax' => $this->tax,
            'subtotal' => $this->subtotal,
            'customerEmail' => $this->customerEmail,
            'customerName' => $this->customerName,
            'customerPhone' => $this->customerPhone,
            'orderItems' => array_map(fn($item) => $item->toArray(), $this->orderItems),
            'address' => array_map(fn($address) => $address->toArray(), $this->addresses),
            'originalSourceOrderNumber' => strval($this->originalSourceOrderNumber),
        ];
    }
}
