<?php

declare(strict_types=1);

namespace OrderProtectionWp\Api\Dto;

class ProductCreateDto
{
    private $productId;
    private $variantId;
    private $name;
    private $sku;
    private $price;
    private $tax;
    private $inventoryType;
    private $inventoryQuantity;
    private $inStock;
    private $productImage;
    private $description;
    private $productType;
    private $status;
    private $bundleProductIds;

    public function __construct(
        $productId,
        $variantId,
        $name,
        $sku,
        $price,
        $tax,
        $inventoryType,
        $inventoryQuantity,
        $inStock,
        $productImage,
        $description,
        $productType,
        $productStatus,
        $bundleProductIds
    ) {
        $this->productId = $productId;
        $this->variantId = $variantId;
        $this->name = $name;
        $this->sku = isset($sku) ? $sku : strval($this->productId);
        $this->price = floatval($price);
        $this->tax = floatVal($tax);
        $this->inventoryType = $inventoryType ?? 'SIMPLE';
        $this->inventoryQuantity = $inventoryQuantity;
        $this->inStock = $inStock;
        $this->productImage = $productImage;
        $this->description = preg_replace('/<img[^>]*>.*?(<\/img>|\/>)/s', '', $description);
        $this->productType = $productType ?? 'SIMPLE';
        $this->status = $productStatus;
        $this->bundleProductIds = $bundleProductIds;
    }

    private function statusMap($status)
    {
        $map = [
            'publish' => 'ACTIVE',
            'draft' => 'DRAFT',
            'trash' => 'DELETED',
            'private' => 'ARCHIVE',
            'pending' => 'DRAFT',
        ];

        return $map[$status];
    }

    private function productTypeMap($productType)
    {
        $map = [
            'variation' => 'SIMPLE',
            'simple' => 'SIMPLE',
            'grouped' => 'GROUPED',
            'variable' => 'SIMPLE', // we convert everything to simple
        ];

        return $map[$productType];
    }

    public function toArray(): array
    {
        return [
            'productId' => strval($this->productId),
            'description' => !empty($this->description) ? $this->description : 'No description provided',
            'variantId' => !empty($this->variantId) ? strval($this->variantId) : null,
            'name' => $this->name,
            'sku' => $this->sku,
            'price' => $this->price,
            'tax' => $this->tax,
            'inventoryType' => $this->inventoryType,
            'inventoryQuantity' => $this->inventoryQuantity,
            'inStock' => $this->inStock,
            'productImage' => $this->productImage,
            'status' => $this->statusMap($this->status),
            'productType' => $this->productTypeMap($this->productType),
            'bundleProductIds' => $this->bundleProductIds,
        ];
    }
}
