/**
 * This is the main entry point for Block Editor blocks scripts used for the `WordPress admin editor`.
 * This file registers blocks dynamically using `registerBlocks` helper method.
 * File names must follow the naming convention to be able to run dynamically.
 *
 * `src/blocks/custom/block_name/manifest.json`.
 * `src/blocks/custom/block_name/block_name.js`.
 *
 * Usage: `WordPress admin editor`.
 */

import domReady from '@wordpress/dom-ready';
import { setDefaultBlockName, updateCategory } from '@wordpress/blocks';
import { SVG, Path } from '@wordpress/components';
import { select } from '@wordpress/data';
import {
	registerBlocks,
	outputCssVariablesGlobal,
	inserter,
	STORE_NAME,
} from '@eightshift/frontend-libs/scripts/editor';
import { Wrapper } from '../../wrapper/wrapper';
import WrapperManifest from '../../wrapper/manifest.json';
import globalSettings from '../../manifest.json';

registerBlocks(
	globalSettings,
	Wrapper,
	WrapperManifest,
	require.context('./../../components', true, /manifest.json$/),
	require.context('./../../custom', true, /manifest.json$/),
	require.context('./../../custom', true, /-block.js$/),
	require.context('./../../custom', true, /-hooks.js$/),
	require.context('./../../custom', true, /-transforms.js$/),
	require.context('./../../custom', true, /-deprecations.js$/),
	require.context('./../../custom', true, /-overrides.js$/),
);

// Output global css variables.
outputCssVariablesGlobal();

// Change the default block to the custom paragraph.
// If changing this block update the blocks filter method in Blocks.php.
domReady(() => {
	const namespace = select(STORE_NAME).getSettingsNamespace();

	setDefaultBlockName(`${namespace}/paragraph`);
});

// Inserter for inserting blocks from console.
inserter();

// Add custom category icon.
updateCategory('orderprotection', {
	icon: (
		<SVG version="1.1" xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" viewBox="0 0 24 24"><Path fill="#1BDC23" d="M12.1,13.1L9.4,11l-1,1.2l3.8,3l7.3-9.3l-1.8-0.1C17.7,5.7,12.1,13.1,12.1,13.1z"/><Path d="M17.5,10.8c-0.9,3-2.7,5.5-5.6,7.5c-1.9-1.1-3.4-2.7-4.4-4.6C6.7,11.9,6.2,9.7,6,7.2c2-0.3,4.1-0.8,6-1.5 c1,0.4,2.1,0.7,3.1,1l1-1.3C14.7,5,13.4,4.6,12,4C9.8,5,7.2,5.6,4.5,5.8C4.6,12.3,6.7,17.3,12,20c4.3-2.7,6.9-6.5,7.4-11.7 C19.5,8.3,17.5,10.8,17.5,10.8z"/></SVG>
 // eslint-disable-line
	)
});
