import { selector } from '@eightshift/frontend-libs/scripts';
import { useDispatch } from '@wordpress/data';
import { useState, useEffect } from '@wordpress/element';

import { LogoIcon } from './logo-icon.js';
import { InfoIcon } from './info-icon.js';
import manifest from '../../../components/fee-widget/manifest.json';

export const FeeWidget = ( { cart, extensions } ) => {
	const wc = window.wc;
	const { extensionCartUpdate } = wc.blocksCheckout;
	const { CART_STORE_KEY } = wc.wcBlocksData;
	const { setCartData } = useDispatch( CART_STORE_KEY );

	const {
		componentClass,
		componentJsClass,
		icons,
	} = manifest;

	const [isChecked, setIsChecked] = useState(false);
	const [feeWidgetFee, setFeeWidgetFee] = useState('$0.00');

	const fetchBody = new FormData();
	fetchBody.append('action', orderProtectionAjaxObject.feeUpdateCallback);
	fetchBody.append(orderProtectionAjaxObject.nonceName, orderProtectionAjaxObject.nonce);

	const fetchFeeRateInitially = async () => {
		const fetchBody = new FormData();
		fetchBody.append('action', orderProtectionAjaxObject.feeInitCallback);
		fetchBody.append(orderProtectionAjaxObject.nonceName, orderProtectionAjaxObject.nonce);

		const response = await fetch(orderProtectionAjaxObject.ajaxUrl, {
			method: 'POST',
			body: fetchBody,
		});

		const res = await response.json();

		if (res.error) {
			console.log(res.error);
			return;
		}

		setFeeWidgetFee(res.data.fee);
	};

	const fetchFeeRate = async (isInputChecked) => {
		fetchBody.append(orderProtectionAjaxObject.feeApplied, isInputChecked ? '1' : '0');

		const response = await fetch(orderProtectionAjaxObject.ajaxUrl, {
			method: 'POST',
			body: fetchBody,
		});

		const res = await response.json();

		if (res.error) {
			console.log(res.error);
			return;
		}

		setFeeWidgetFee(res.data.fee);
	};

	const classnames = (...args) => {
		return args.filter(Boolean).join(' ');
	};

	const errorElementClass = `${selector(componentClass, componentClass, 'error')} ${selector(componentClass, 'js-orderprotection-error')}`;

	const checkboxClass = `${selector(componentClass, componentClass, 'check')} ${selector(componentClass, componentJsClass)}`;

	const labelClass = `${selector(componentClass, componentClass, 'label')} ${selector(componentClass, 'js-orderprotection-label')}`;

	useEffect(() => {
		fetchFeeRateInitially();
		setIsChecked(cart.cartFees.length > 0);
	}, []);

	const handleCheck = () => {
		setIsChecked(!isChecked);
		// Update the cart object and remove the fee if the fee is unchecked.
		if (isChecked) {
			cart.cartFees = cart.cartFees.filter((fee) => fee.name !== 'Order Protection');
		}
		setCartData( cart );
		fetchFeeRate(isChecked);
		// extensionCartUpdate({
		// 	namespace: 'order-protection-cart-update',
		// 	data: {
		// 		cart: cart,
		// 	},
		// });
	};

	return (
		<div className={componentClass}>
				<p className={errorElementClass}></p>
				<div className={`${componentClass}__wrap`}>
					<div className={`${componentClass}__figure`}>
						<div className={`${componentClass}__images`}>
							<LogoIcon />
							<InfoIcon />
						</div>
						<small className={`${componentClass}__desc`}>'Protection for Damage, Loss, Theft & More!'</small>
					</div>
					<div className={`${componentClass}__selector`}>
						<span className={`${componentClass}__subtotal js-fee-subtotal`}>
							{feeWidgetFee}
						</span>
						<label
							aria-label='Add Order Protection to your order'
							className={labelClass}
							for={componentClass}>
								<input
									type="checkbox"
									name={componentClass}
									id={componentClass}
									className={checkboxClass}
									value="1"
									checked={isChecked}
									onChange={handleCheck}
								/>
							<span className={`${componentClass}__track`}>
								<span className={`${componentClass}__indicator`}>
									<span className= {`${componentClass}__checkmark`}></span>
								</span>
							</span>
						</label>
					</div>
				</div>
				{/*	Modal goes here, we won't render it atm. */}
			</div>
	);
};
