export class HandleInputChange {
	constructor(options) {
		Object.assign(this, options);

		this.feeSubtotalElement = document.querySelector(this.feeSubtotalClass);
		this.errorElement = document.querySelector(this.errorElementClass);
		this.isInputChecked = this.input.checked;

		this.IS_SHOWN_CLASS = 'is-shown';
	}

	init() {
		document.addEventListener('click', this.handleClick.bind(this));

		this.observeCartChanges();
		this.removeGarlicAutoSave();
	}

	handleClick(event) {
		const labelElement = event.target.closest(this.labelClass);
		const inputElement = labelElement?.querySelector(this.inputClass);
		const reloadPage = labelElement?.dataset.reload === 'true';

		if (inputElement) {
			event.preventDefault();
			this.toggleInput();
			this.makeFetchRequest(reloadPage);
		}
	}

	observeCartChanges() {
		const cartObserver = new PerformanceObserver((list) => {
			list.getEntries().forEach((entry) => {
				if (entry.entryType === 'resource' && entry.name.includes('wc/store/v1/batch?_locale=user')) {
					this.updateWidgetFee();
				}
			});
		});

		cartObserver.observe({entryTypes: ['resource']});
	}

	removeGarlicAutoSave() {
		const garlicAutoSave = document.querySelector('.garlic-auto-save');
		if (garlicAutoSave) {
			garlicAutoSave.classList.remove('garlic-auto-save');
			garlicAutoSave.removeAttribute('data-parsley-multiple');
			this.removeLocalStorageItemsContaining('orderprotection-fee');
		}
	}

	toggleInput() {
		this.input.checked = !this.input.checked;
		this.isInputChecked = this.input.checked;
	}

	makeFetchRequest(reloadPage) {
		this.clearError();
		fetch(this.getAjaxUrl(), {
			method: 'POST',
			body: this.getFetchBody(),
		})
			.then(() => {
				document.dispatchEvent(new CustomEvent('added_to_cart', {bubbles: true, cancelable: true}));
				if (reloadPage) {
					location.reload();
				}
			})
			.catch((error) => this.showError(error));
	}

	updateWidgetFee() {
		this.clearError();
		fetch(this.getAjaxUrl(), {
			method: 'POST',
			body: this.getFetchBody(),
		})
			.then((response) => response.text())
			.then((response) => {
				this.feeSubtotalElement.innerHTML = JSON.parse(response).data.fee;
			})
			.catch((error) => this.showError(error));
	}

	getAjaxUrl() {
		return orderProtectionAjaxObject.ajaxUrl;
	}

	getFetchBody() {
		const fetchBody = new FormData();
		fetchBody.append('action', orderProtectionAjaxObject.feeUpdateCallback);
		fetchBody.append(orderProtectionAjaxObject.feeApplied, this.isInputChecked ? '1' : '0');
		fetchBody.append(orderProtectionAjaxObject.nonceName, orderProtectionAjaxObject.nonce);
		return fetchBody;
	}

	clearError() {
		this.errorElement.classList.remove(this.IS_SHOWN_CLASS);
		this.errorElement.innerHTML = "";
	}

	showError(error) {
		this.errorElement.innerHTML = orderProtectionAjaxObject.errorMessage + ' ' + error.message;
		this.errorElement.classList.add(this.IS_SHOWN_CLASS);
	}

	removeLocalStorageItemsContaining(str) {
		for (let i = localStorage.length - 1; i >= 0; i--) {
			const key = localStorage.key(i);
			if (key.includes(str)) {
				localStorage.removeItem(key);
			}
		}
	}
}
