<?php

/**
 * The file that holds a CartFeeAddition class.
 *
 * @package OrderProtectionWp\Cart
 */

declare(strict_types=1);

namespace OrderProtectionWp\Cart;

use OrderProtectionWp\Ajax\AbstractAjax;
use OrderProtectionWp\Helpers\Cart;
use OrderProtectionWp\OrderProtectionApi\FetchOrderProtectionRatesInterface;

/**
 * CartFeeAddition class.
 *
 * @since 1.0.0
 */
class CartFeeAddition extends AbstractAjax
{
    public const IS_PRIVATE = false;
    public const NONCE_ACTION = 'orderprotection_fee_nonce';
    public const NONCE_NAME = 'fee_nonce';
    public const ORDER_PROTECTION_FEE_APPLIED_STRING = 'orderprotection_fee_applied';
    public const USER_PREFERENCE = 'orderprotection_user_preference';
    public const AJAX_CALLBACK_HANDLER = 'orderprotection_fee_update';

    private Cart $cartHelper;

    /**
     * Class dependencies
     *
     * @param FetchOrderProtectionRatesInterface $fetchOrderProtectionRates Order Protection api rates dependency.
     */
    public function __construct(Cart $cart)
    {
        $this->cartHelper = $cart;
    }

    /**
     * Callback method for Ajax handler.
     *
     * @return void
     * @since 1.0.0
     */
    public function getAjaxCallback(): void
    {
        if (
            !isset($_POST[self::NONCE_NAME]) ||
            !wp_verify_nonce(sanitize_key($_POST[self::NONCE_NAME]), self::NONCE_ACTION)
        ) {
            wp_send_json_error(esc_html__('Number not only once is invalid', 'orderprotection-wp'), 404);
        }

        if (!isset($_POST[self::ORDER_PROTECTION_FEE_APPLIED_STRING])) {
            wp_send_json_error(esc_html__('No fee to apply', 'orderprotection-wp'), 404);
        }

        $settings = $this->cartHelper->getSettings();
        if ($_POST[self::ORDER_PROTECTION_FEE_APPLIED_STRING] === '0') {
            $this->cartHelper->setUserPreference(false);
            $this->cartHelper->removeProtection();

            wp_send_json_success([
                'fee' => \html_entity_decode(wp_strip_all_tags(wc_price($settings['fee']))),
                'message' => esc_html__('Order Protection fee modified', 'orderprotection-wp')
            ], 200);

            return;
        }

        $this->cartHelper->setUserPreference(true);
        $this->cartHelper->addProtection();

        wp_send_json_success([
            'fee' => \html_entity_decode(wp_strip_all_tags(wc_price($settings['fee']))),
            'message' => esc_html__('Order Protection fee modified', 'orderprotection-wp')
        ], 200);
    }
}
