<?php

/**
 * The file that holds a CartFeeAddition class.
 *
 * @package OrderProtectionWp\Cart
 */

declare(strict_types=1);

namespace OrderProtectionWp\Cart;

use OrderProtectionWp\Ajax\AbstractAjax;
use OrderProtectionWp\Helpers\Cart;

/**
 * CartFeeInitialization class.
 *
 * @since 1.0.0
 */
class CartFeeInitialization extends AbstractAjax
{
	public const AJAX_CALLBACK_HANDLER = 'orderprotection_fee_init';
	public const IS_PRIVATE = false;
	public const NONCE_ACTION = 'orderprotection_fee_nonce';
	public const NONCE_NAME = 'fee_nonce';

	private Cart $cartHelper;

	public function __construct(Cart $cart)
	{
		$this->cartHelper = $cart;
	}

	/**
	 * Callback method for Ajax handler.
	 *
	 * @return void
	 * @since 1.0.0
	 */
	public function getAjaxCallback(): void
	{
		if (
			!isset($_POST[self::NONCE_NAME]) ||
			!wp_verify_nonce(sanitize_key($_POST[self::NONCE_NAME]), self::NONCE_ACTION)
		) {
			wp_send_json_error(esc_html__('Number not only once is invalid', 'orderprotection-wp'), 404);
		}

		error_log('fee initialization ajax callback');

		$settings = $this->cartHelper->getSettings();
		$hidden = $settings['hidden'];

		if (!$hidden) {
			error_log('here');
			if ($settings['default_on']) {
				error_log('adding_protection');
				$this->cartHelper->addProtection();
			}
		}


		wp_send_json_success([
			'fee' => \html_entity_decode(wp_strip_all_tags(wc_price($settings['fee']))),
			'message' => esc_html__('Order Protection fee updated', 'orderprotection-wp')
		], 200);
	}
}
