<?php

/**
 * The file that defines the project entry point class.
 *
 * A class definition that includes attributes and functions used across both the
 * public side of the site and the admin area.
 *
 * @package OrderProtectionWp\Config
 */

declare(strict_types=1);

namespace OrderProtectionWp\Config;

use OrderProtectionWpVendor\EightshiftLibs\Config\AbstractConfigData;

/**
 * The project config class.
 *
 * @since 1.0.0
 */
class Config extends AbstractConfigData
{
    /**
     * Method that returns project name.
     *
     * Generally used for naming assets handlers, languages, etc.
     *
     * @since 1.0.0
     */
    public static function getProjectName(): string
    {
        return 'OrderProtection';
    }

    /**
     * Method that returns project version.
     *
     * Generally used for versioning asset handlers while enqueueing them.
     *
     * @since 1.0.0
     */
    public static function getProjectVersion(): string
    {
        return '1.1.15';
    }

    /**
     * Method that returns project REST-API namespace.
     *
     * Used for namespacing projects REST-API routes and fields.
     *
     * @since 1.0.0
     *
     * @return string Project name.
     */
    public static function getProjectRoutesNamespace(): string
    {
        return static::getProjectName();
    }

    /**
     * Method that returns project REST-API version.
     *
     * Used for versioning projects REST-API routes and fields.
     *
     * @since 1.0.0
     *
     * @return string Project route version.
     */
    public static function getProjectRoutesVersion(): string
    {
        return 'v1';
    }
}
