<?php

/**
 * The Blog_Taxonomy specific functionality.
 *
 * @package OrderProtectionWp\CustomTaxonomy
 */

declare(strict_types=1);

namespace OrderProtectionWp\CustomTaxonomy;

use OrderProtectionWpVendor\EightshiftLibs\CustomTaxonomy\AbstractTaxonomy;

/**
 * Class ClaimResolutionTaxonomy
 */
class ClaimResolutionTaxonomy extends AbstractTaxonomy
{
	/**
	 * Taxonomy slug constant.
	 *
	 * @var string
	 */
	public const TAXONOMY_SLUG = 'claim_resolution';

	/**
	 * Taxonomy post type slug constant.
	 *
	 * @var string
	 */
	public const TAXONOMY_POST_TYPE_SLUG = 'shop-order';

	/**
	 * Rest API Endpoint slug constant.
	 *
	 * @var string
	 */
	public const REST_API_ENDPOINT_SLUG = 'claim-resolutions';

	/**
	 * Get the slug of the custom taxonomy
	 *
	 * @return string Custom taxonomy slug.
	 */
	protected function getTaxonomySlug(): string
	{
		return static::TAXONOMY_SLUG;
	}

	/**
	 * Get the post type slug(s) that use the taxonomy.
	 *
	 * @return string|array<string> Custom post type slug or an array of slugs.
	 */
	protected function getPostTypeSlug()
	{
		return self::TAXONOMY_POST_TYPE_SLUG;
	}

	/**
	 * Get the arguments that configure the custom taxonomy.
	 *
	 * @return array<mixed> Array of arguments.
	 */
	protected function getTaxonomyArguments(): array
	{
		$nouns = [
			\esc_html_x(
				'Claim Resolution',
				'taxonomy upper case singular name',
				'order-protection-wp'
			),
			\esc_html_x(
				'Claim Resolution',
				'taxonomy lower case singular name',
				'order-protection-wp'
			),
			\esc_html_x(
				'Claim Resolutions',
				'taxonomy upper case plural name',
				'order-protection-wp'
			),
			\esc_html_x(
				'Claim Resolutions',
				'taxonomy lower case plural name',
				'order-protection-wp'
			),
		];

		$labels = $this->getGeneratedLabels($nouns);

		return [
			'hierarchical' => false,
			'label' => $nouns[0],
			'labels' => $labels,
			'show_ui' => false,
			'show_admin_column' => true,
			'show_in_nav_menus' => false,
			'public' => false,
			'show_in_rest' => true,
			'query_var' => true,
			'rest_base' => static::REST_API_ENDPOINT_SLUG,
			'rewrite' => [
				'hierarchical' => false,
				'with_front' => false,
			],
		];
	}
}
