<?php

/**
 * The file that is an ShopOrderCustomAdminColumn class.
 *
 * @package OrderProtectionWp\CustomTaxonomy;
 */

declare(strict_types=1);

namespace OrderProtectionWp\CustomTaxonomy;

use OrderProtectionWpVendor\EightshiftLibs\Services\ServiceInterface;

/**
 * ShopOrderCustomAdminColumn class.
 */
class ShopOrderCustomAdminColumn implements ServiceInterface
{
	private const COLUMN_NAME = 'claim_resolution';

	/**
	 * Register all the hooks
	 *
	 * @return void
	 */
	public function register(): void
	{
		// Add admin column for the claim-resolution taxonomy in the shop order list.
		add_filter('manage_edit-shop_order_columns', [$this, 'addClaimResolutionColumn']);
		add_action('manage_shop_order_posts_custom_column', [$this, 'addClaimResolutionColumnContent'], 10, 2);
	}

	public function addClaimResolutionColumn($columns): array
	{
		$columns[self::COLUMN_NAME] = esc_html__('Claim Resolution', 'order-protection-wp');

		return $columns;
	}

	public function addClaimResolutionColumnContent($column, $postId): void
	{
		if ($column === self::COLUMN_NAME) {
			$claimResolution = wp_get_object_terms($postId, ClaimResolutionTaxonomy::TAXONOMY_SLUG);

			$resolutionList = array_map(static function ($tag) {
				return esc_html($tag->name);
			}, $claimResolution);

			echo implode(', ', $resolutionList);
		}
	}
}
