<?php

/**
 * File that holds cryptor interface
 *
 * @package OrderProtectionWp\Encryption
 */

declare(strict_types=1);

namespace OrderProtectionWp\Encryption;

/**
 * Cryptor interface
 *
 * @since 1.0.0
 */
interface Cryptor
{
	/**
	 * Encrypt the given value
	 *
	 * @since 1.0.0
	 *
	 * @param string $value Value to encrypt.
	 *
	 * @return string Encrypted string.
	 */
	public function encrypt(string $value): string;

	/**
	 * Decrypt the given value
	 *
	 * @since 1.0.0
	 *
	 * @param string $payload Value to decrypt.
	 *
	 * @return mixed Decrypted payload.
	 */
	public function decrypt(string $payload);

	/**
	 * Get the encryption key that the cryptor is currently using
	 *
	 * @since 1.0.0
	 *
	 * @return mixed Key value used for encryption.
	 */
	public function getKey();

	/**
	 * Set the encryption key that the cryptor will use
	 *
	 * @since 1.0.0
	 *
	 * @param string|null $value Optional value to set the key with.
	 */
	public function setKey(?string $value = null): void;
}
