<?php

/**
 * File containing an abstract class for holding Assets Manifest functionality.
 *
 * It is used to provide manifest.json file location used with Webpack to fetch correct file locations.
 *
 * @package OrderProtectionWp\Manifest
 */

declare(strict_types=1);

namespace OrderProtectionWp\Manifest;

use OrderProtectionWp\Config\Config;
use OrderProtectionWpVendor\EightshiftLibs\Manifest\AbstractManifest;

/**
 * Class Manifest
 */
class Manifest extends AbstractManifest
{
	/**
	 * Manifest item filter name constant.
	 *
	 * @since 1.0.0
	 *
	 * @var string
	 */
	public const MANIFEST_ITEM = 'manifest-item';

	/**
	 * Register all hooks. Changed filter name to manifest.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public function register(): void
	{
		\add_action('init', [$this, 'setAssetsManifestRaw']);
		\add_filter(static::MANIFEST_ITEM, [$this, 'getAssetsManifestItem']);
	}

	/**
	 * Manifest file path getter.
	 *
	 * @since 1.0.0
	 *
	 * @return string
	 */
	public function getManifestFilePath(): string
	{
		return Config::getProjectPath() . '/public/manifest.json';
	}
}
