<?php

/**
 * Send order to the Order Protection API
 *
 * @package OrderProtectionWp\OrderProtectionApi
 */

declare(strict_types=1);

namespace OrderProtectionWp\OrderProtectionApi;

use Exception;
use OrderProtectionWp\Api\Creatable;
use OrderProtectionWp\Encryption\Cryptor;
use OrderProtectionWp\Settings\PluginSettings;

/**
 * Send data to Order Protection API
 */
class CreateOrder implements Creatable
{
    // Prod URL: https://production.orderprotection.com/api/v1/orders
    // public const API_URI = 'https://wolzey.ngrok.app/v1/orders';

    public const API_URI = 'https://api.production.orderprotection.com/v1/orders';

    /**
     * Encryption member variable
     *
     * @var Cryptor
     */
    private Cryptor $encryptor;

    /**
     * Class dependencies
     *
     * @param Cryptor $encryptor Encryption dependency.
     */
    public function __construct(Cryptor $encryptor)
    {
        $this->encryptor = $encryptor;
    }

    /**
     * @deprecated
     * Send data to the Order Protection API
     *
     * @param array<mixed> $data Data to send.
     *
     * @codeCoverageIgnore Ignoring this one, as it's just a wrapper around the wp_remote_post function.
     *
     * @throws Exception Exception in the case the API key is not set.
     *
     * @return mixed
     */
    public function create(array $data, $parent_id = '')
    {
        $token = get_option(PluginSettings::OPTION_OP_TOKEN);

        if (empty($token)) {
            throw new Exception(esc_html__('Order Protection API token is not set.', 'order-protection-wp'));
        }

        if (!empty($_ENV['IS_TEST']) && $_ENV['IS_TEST'] === 'true') {
            error_log('IS_TEST: ' . $_ENV['IS_TEST']);
            return ['success' => true];
        }

        return wp_remote_post(self::API_URI, [
            'body' => wp_json_encode($data),
            'headers' => [
                'Content-Type' => 'application/json',
                'Authorization' => "Bearer $token",
            ]
        ]);
    }
}
