<?php

/**
 * Send order to the Order Protection API
 *
 * @package OrderProtectionWp\OrderProtectionApi
 */

declare(strict_types=1);

namespace OrderProtectionWp\OrderProtectionApi;

use Exception;
use OrderProtectionWp\Api\Creatable;
use OrderProtectionWp\Encryption\Cryptor;
use OrderProtectionWp\OrderProtectionApi\Client;

/**
 * Send data to Order Protection API
 */
class CreateProduct implements Creatable
{
	private Client $client;
  // Prod URL: https://production.orderprotection.com/api/v1/orders
  // public const API_URI = 'https://wolzey.ngrok.app/v1/orders';

	public const API_URI = 'https://api.production.orderprotection.com/v2/products';
  /**
   * Encryption member variable
   *
   * @var Cryptor
   */
  private Cryptor $encryptor;

  /**
   * Class dependencies
   *
   * @param Cryptor $encryptor Encryption dependency.
   */
  public function __construct(Cryptor $encryptor, Client $client)
  {
	$this->client = $client;
    $this->encryptor = $encryptor;
  }

  /**
   * Send data to the Order Protection API
   *
   * @param array<mixed> $data Data to send.
   *
   * @codeCoverageIgnore Ignoring this one, as it's just a wrapper around the wp_remote_post function.
   *
   * @throws Exception Exception in the case the API key is not set.
   *
   * @return mixed
   */
	public function create(array $data, string $parent_id = '') {
		return $this->client->createProduct($data, $parent_id);
	}
}
