<?php

/**
 * The file that defines a factory for activating / deactivating plugin.
 *
 * @package OrderProtectionWp
 */

declare(strict_types=1);

namespace OrderProtectionWp;

use OrderProtectionWp\Main\Main;

/**
 * The plugin factory class.
 *
 * @since 1.0.0
 */
class PluginFactory
{
	/**
	 * Activate the plugin.
	 *
	 * @since 1.0.0
	 */
	public static function activate(): void
	{
		(new Activate())->activate();
	}

	/**
	 * Deactivate the plugin.
	 *
	 * @since 1.0.0
	 */
	public static function deactivate(): void
	{
		(new Deactivate())->deactivate();
	}

	/**
	 * Create and return an instance of the plugin.
	 *
	 * This always returns a shared instance.
	 *
	 * @since 1.0.0
	 *
	 * @param array<string, string[]> $prefixes List of PSR-4 prefixes.
	 * @param string $namespace Main plugin namespace.
	 *
	 * @return Main Plugin instance.
	 */
	public static function create(array $prefixes, string $namespace): Main
	{
		static $plugin = null;

		if ($plugin === null) {
			$plugin = new Main($prefixes, $namespace);
		}

		return $plugin;
	}
}
