<?php

declare(strict_types=1);

namespace OrderProtectionWp\Resolutions;

use WC_Order;
use OrderProtectionWp\CustomTaxonomy\ClaimResolutionTaxonomy;

class ResolutionManager
{
    private array $strategies = [];

    public function registerStrategy(string $type, ResolutionStrategyInterface $strategy): void
    {
        $this->strategies[strtolower($type)] = $strategy;
    }

    public function handleResolution(WC_Order $order, array $resolution, $claimId): void
    {
        $type = strtolower($resolution['type']);

        // Add note to order
        error_log("managing resolution");
        error_log("claimId: " . $claimId);

        if (isset($claimId)) {
            $order->add_order_note("OrderProtection claim: $claimId was resolved with resolution type: $type");
        }

        // Set taxonomy term
        wp_set_object_terms($order->get_id(), $type, ClaimResolutionTaxonomy::TAXONOMY_SLUG, true);

        // Handle resolution if strategy exists
        if (isset($this->strategies[$type])) {
            error_log("strategy found for resolution type: $type");
            $this->strategies[$type]->handle($order, $resolution);
        } else {
            error_log("no strategy found for resolution type: $type");
        }
    }
}
