<?php

/**
 * The file that holds a CartToggle class.
 *
 * @package OrderProtectionWp\Shortcode
 */

declare(strict_types=1);

namespace OrderProtectionWp\Shortcode;

use OrderProtectionWp\Settings\PluginSettings;
use OrderProtectionWpVendor\EightshiftLibs\Helpers\Components;
use OrderProtectionWpVendor\EightshiftLibs\Services\ServiceInterface;

/**
 * CartToggle class.
 *
 * Creates the [orderprotection-cart-toggle] shortcode.
 */
class CartToggle implements ServiceInterface
{
	/**
	 * Register all the hooks
	 *
	 * @return void
	 */
	public function register(): void
	{
		add_action('init', [$this, 'initShortcode']);
	}

	/**
	 * Initialize shortcode
	 *
	 * @return void
	 */
	public function initShortcode()
	{
		add_shortcode('orderprotection-cart-toggle', [$this, 'cartToggle']);
	}

	/**
	 * Create Shortcode for displaying the OP Widget.
	 *
	 * @return string Returns an empty string when OrderProtection isn't active.
	 */
	public function cartToggle(): string
	{
		if (!PluginSettings::isOrderprotectionActive()) {
			return '';
		}

		return Components::render('fee-widget');
	}
}
