<?php

/**
 * Holds the class that will handle the Order cancellation.
 *
 * If an order is cancelled we will mark it as cancelled in OrderProtection. This ensures that you are not billed for
 * protection costs on an order that was refunded due to a cancellation.
 *
 * @package OrderProtectionWp\WooCommerce
 */

declare(strict_types=1);

namespace OrderProtectionWp\WooCommerce;

use OrderProtectionWp\OrderProtectionApi\Client;
use OrderProtectionWpVendor\EightshiftLibs\Services\ServiceInterface;

class SendOrderCancellationToApi implements ServiceInterface
{
	public Client $client;

	public function __construct(Client $client)
	{
		$this->client = $client;
	}

	public function register(): void
	{
		add_action( 'woocommerce_order_status_cancelled', [$this, 'sendOrderCancellation'] );
	}

	public function sendOrderCancellation( $order_id )
	{
		$this->client->cancelOrder( strval( $order_id ) );
	}
}
