<?php declare(strict_types=1);

/**
 * @package OrderProtectionWp\SyncProductDetails.php
 *
 * This package syncs all Products available in the store with the OrderPRotection API
 */

namespace OrderProtectionWp\WooCommerce;

use OrderProtectionWPVendor\EightshiftLibs\Services\ServiceInterface;
use Automattic\WooCommerce\Enums\ProductStatus;
use Automattic\WooCommerce\Enums\ProductType;

class SyncProductDetails implements ServiceInterface {
	public function register(): void {
		add_action('sync_orderprotection_products', [$this, 'syncProductDetails']);
	}

	private SendProductDetailsToApi $sendProductDetails;

	public function __construct(SendProductDetailsToApi $sendProductDetails) {
		$this->sendProductDetails = $sendProductDetails;
	}


	public function syncProductDetails() {
		$products = $this->getProducts();

		array_map(function ($product) {
			$this->sendProductDetails->prepareOrderProtectionProduct($product->get_id());
		}, $products);
	}

	private function getProducts() {
		return wc_get_products(
			[
				'status' => ProductStatus::PUBLISH,
				'type' => [
					ProductType::SIMPLE,
					ProductType::VARIABLE,
					ProductType::GROUPED,
				]
			]
		);
	}
}

