<?php

/**
 * The class file that holds abstract class for WPCLI
 *
 * @package EightshiftLibs\Cli
 */

declare(strict_types=1);

namespace OrderProtectionWpVendor\EightshiftLibs\Cli;

use OrderProtectionWpVendor\EightshiftLibs\AdminMenus\AdminMenuCli;
use OrderProtectionWpVendor\EightshiftLibs\AdminMenus\AdminReusableBlocksMenuCli;
use OrderProtectionWpVendor\EightshiftLibs\AdminMenus\AdminSubMenuCli;
use OrderProtectionWpVendor\EightshiftLibs\AdminMenus\ReusableBlocksHeaderFooterCli;
use OrderProtectionWpVendor\EightshiftLibs\AnalyticsGdpr\AnalyticsGdprCli;
use OrderProtectionWpVendor\EightshiftLibs\BlockPatterns\BlockPatternCli;
use OrderProtectionWpVendor\EightshiftLibs\Blocks\BlocksCli;
use OrderProtectionWpVendor\EightshiftLibs\Blocks\UseComponentCli;
use OrderProtectionWpVendor\EightshiftLibs\Blocks\UseBlockCli;
use OrderProtectionWpVendor\EightshiftLibs\Blocks\UseAssetsCli;
use OrderProtectionWpVendor\EightshiftLibs\Blocks\UseGlobalAssetsCli;
use OrderProtectionWpVendor\EightshiftLibs\Blocks\UseManifestCli;
use OrderProtectionWpVendor\EightshiftLibs\Blocks\UseVariationCli;
use OrderProtectionWpVendor\EightshiftLibs\Blocks\UseWrapperCli;
use OrderProtectionWpVendor\EightshiftLibs\Cli\ParentGroups\CliBoilerplate;
use OrderProtectionWpVendor\EightshiftLibs\Cli\ParentGroups\CliCreate;
use OrderProtectionWpVendor\EightshiftLibs\Cli\ParentGroups\CliRun;
use OrderProtectionWpVendor\EightshiftLibs\Cli\ParentGroups\CliBlocks;
use OrderProtectionWpVendor\EightshiftLibs\Cli\ParentGroups\CliInit;
use OrderProtectionWpVendor\EightshiftLibs\Columns\Media\WebPMediaColumnCli;
use OrderProtectionWpVendor\EightshiftLibs\Config\ConfigCli;
use OrderProtectionWpVendor\EightshiftLibs\ConfigProject\ConfigProjectCli;
use OrderProtectionWpVendor\EightshiftLibs\Setup\PluginManageCli;
use OrderProtectionWpVendor\EightshiftLibs\View\EscapedViewCli;
use OrderProtectionWpVendor\EightshiftLibs\CustomMeta\AcfMetaCli;
use OrderProtectionWpVendor\EightshiftLibs\Setup\SetupCli;
use OrderProtectionWpVendor\EightshiftLibs\CustomPostType\PostTypeCli;
use OrderProtectionWpVendor\EightshiftLibs\CustomTaxonomy\TaxonomyCli;
use OrderProtectionWpVendor\EightshiftLibs\Enqueue\Admin\EnqueueAdminCli;
use OrderProtectionWpVendor\EightshiftLibs\Enqueue\Blocks\EnqueueBlocksCli;
use OrderProtectionWpVendor\EightshiftLibs\Enqueue\Theme\EnqueueThemeCli;
use OrderProtectionWpVendor\EightshiftLibs\Services\ServiceExampleCli;
use OrderProtectionWpVendor\EightshiftLibs\I18n\I18nCli;
use OrderProtectionWpVendor\EightshiftLibs\Login\LoginCli;
use OrderProtectionWpVendor\EightshiftLibs\Main\MainCli;
use OrderProtectionWpVendor\EightshiftLibs\Manifest\ManifestCli;
use OrderProtectionWpVendor\EightshiftLibs\Media\MediaCli;
use OrderProtectionWpVendor\EightshiftLibs\Menu\MenuCli;
use OrderProtectionWpVendor\EightshiftLibs\ModifyAdminAppearance\ModifyAdminAppearanceCli;
use OrderProtectionWpVendor\EightshiftLibs\Rest\Fields\FieldCli;
use OrderProtectionWpVendor\EightshiftLibs\Rest\Routes\RouteCli;
use OrderProtectionWpVendor\EightshiftLibs\Db\ExportCli;
use OrderProtectionWpVendor\EightshiftLibs\Db\ImportCli;
use OrderProtectionWpVendor\EightshiftLibs\Geolocation\GeolocationCli;
use OrderProtectionWpVendor\EightshiftLibs\GitIgnore\GitIgnoreCli;
use OrderProtectionWpVendor\EightshiftLibs\Init\InitAllCli;
use OrderProtectionWpVendor\EightshiftLibs\Init\InitBlocksCli;
use OrderProtectionWpVendor\EightshiftLibs\Init\InitHeaderFooter;
use OrderProtectionWpVendor\EightshiftLibs\Init\InitPluginCli;
use OrderProtectionWpVendor\EightshiftLibs\Init\InitProjectCli;
use OrderProtectionWpVendor\EightshiftLibs\Init\InitThemeCli;
use OrderProtectionWpVendor\EightshiftLibs\Media\RegenerateWebPMediaCli;
use OrderProtectionWpVendor\EightshiftLibs\Media\UseWebPMediaCli;
use OrderProtectionWpVendor\EightshiftLibs\Misc\VersionCli;
use OrderProtectionWpVendor\EightshiftLibs\Readme\ReadmeCli;
use OrderProtectionWpVendor\EightshiftLibs\Rest\Routes\LoadMore\LoadMoreRouteCli;
use OrderProtectionWpVendor\EightshiftLibs\ThemeOptions\ThemeOptionsCli;
use OrderProtectionWpVendor\EightshiftLibs\WpCli\WpCli;
use ReflectionClass;
// phpcs:ignore SlevomatCodingStandard.Namespaces.UnusedUses.UnusedUse
use Exception;
use WP_CLI;

/**
 * Class Cli
 */
class Cli
{
	/**
	 * All commands defined as parent list commands.
	 *
	 * @var class-string[]
	 */
	public const PARENT_COMMANDS = [
		CliCreate::class,
		CliRun::class,
		CliBlocks::class,
		CliInit::class,
	];

	/**
	 * All commands that are service classes type. Command prefix - create.
	 *
	 * @var class-string[]
	 */
	public const CREATE_COMMANDS = [
		AdminMenuCli::class,
		AdminReusableBlocksMenuCli::class,
		AdminSubMenuCli::class,
		ReusableBlocksHeaderFooterCli::class,
		AnalyticsGdprCli::class,
		WebPMediaColumnCli::class,
		ConfigCli::class,
		ConfigProjectCli::class,
		AcfMetaCli::class,
		PostTypeCli::class,
		TaxonomyCli::class,
		EnqueueAdminCli::class,
		EnqueueBlocksCli::class,
		EnqueueThemeCli::class,
		GeolocationCli::class,
		GitIgnoreCli::class,
		I18nCli::class,
		LoginCli::class,
		MainCli::class,
		ManifestCli::class,
		MediaCli::class,
		MenuCli::class,
		ModifyAdminAppearanceCli::class,
		ReadmeCli::class,
		FieldCli::class,
		RouteCli::class,
		LoadMoreRouteCli::class,
		ServiceExampleCli::class,
		SetupCli::class,
		ThemeOptionsCli::class,
		EscapedViewCli::class,
		WpCli::class,
	];

	/**
	 * All commands that can be used on a WP project directly from the libs. Command prefix - run.
	 *
	 * @var class-string[]
	 */
	public const RUN_COMMANDS = [
		ExportCli::class,
		ImportCli::class,
		RegenerateWebPMediaCli::class,
		UseWebPMediaCli::class,
		VersionCli::class,
		PluginManageCli::class,
	];

	/**
	 * All commands used for block editor. Command prefix - blocks.
	 *
	 * @var class-string[]
	 */
	public const BLOCKS_COMMANDS = [
		BlockPatternCli::class,
		BlocksCli::class,
		UseAssetsCli::class,
		UseBlockCli::class,
		UseComponentCli::class,
		UseGlobalAssetsCli::class,
		UseManifestCli::class,
		UseVariationCli::class,
		UseWrapperCli::class,
	];

	/**
	 * All commands used for setting up. Command prefix - init.
	 *
	 * @var class-string[]
	 */
	public const INIT_COMMANDS = [
		InitAllCli::class,
		InitBlocksCli::class,
		InitHeaderFooter::class,
		InitPluginCli::class,
		InitProjectCli::class,
		InitThemeCli::class,
	];

	/**
	 * Define all classes to register for normal WP.
	 *
	 * @return class-string[]
	 */
	public function getCommandsClasses(): array
	{
		return [
			...static::CREATE_COMMANDS,
			...static::BLOCKS_COMMANDS,
			...static::INIT_COMMANDS,
			...static::RUN_COMMANDS
		];
	}

	/**
	 * Run all CLI commands for normal WPCLI.
	 *
	 * @param string $commandParentName Define top level commands name.
	 *
	 * @throws Exception Exception if the class doesn't exist.
	 *
	 * @return void
	 */
	public function load(string $commandParentName): void
	{
		// Duplicate condition because WP_CLI will throw error on the project.
		if (!\getenv('ES_TEST') && \defined('WP_CLI')) {
			// Top Level command name.
			WP_CLI::add_command($commandParentName, new CliBoilerplate());

			// Register all top level commands.
			foreach (self::PARENT_COMMANDS as $item) {
				$reflectionClass = new ReflectionClass($item);
				$class = $reflectionClass->newInstanceArgs();
				$name = $reflectionClass->getConstant('COMMAND_NAME');

				WP_CLI::add_command("{$commandParentName} {$name}", $class);
			}
		}

		foreach ($this->getCommandsClasses() as $item) {
			$reflectionClass = new ReflectionClass($item);
			$class = $reflectionClass->newInstanceArgs([$commandParentName]);

			if ($class instanceof CliInterface) {
				$class->register();
			}
		}
	}
}
