<?php

/**
 * Class that registers WPCLI command for Manifest.
 *
 * @package EightshiftLibs\Manifest
 */

declare(strict_types=1);

namespace OrderProtectionWpVendor\EightshiftLibs\Manifest;

use OrderProtectionWpVendor\EightshiftLibs\Cli\AbstractCli;
use OrderProtectionWpVendor\EightshiftLibs\Cli\ParentGroups\CliCreate;
use OrderProtectionWpVendor\EightshiftLibs\Helpers\Components;

/**
 * Class ManifestCli
 */
class ManifestCli extends AbstractCli
{
	/**
	 * Get WPCLI command parent name
	 *
	 * @return string
	 */
	public function getCommandParentName(): string
	{
		return CliCreate::COMMAND_NAME;
	}

	/**
	 * Get WPCLI command name
	 *
	 * @return string
	 */
	public function getCommandName(): string
	{
		return 'manifest';
	}

	/**
	 * Get WPCLI command doc
	 *
	 * @return array<string, array<int, array<string, bool|string>>|string>
	 */
	public function getDoc(): array
	{
		return [
			'shortdesc' => 'Create manifest service class.',
			'longdesc' => $this->prepareLongDesc("
				## USAGE

				Used to create manifest service class to register assets manifest functionality like getting fonts from your project.

				## EXAMPLES

				# Create service class:
				$ wp {$this->commandParentName} {$this->getCommandParentName()} {$this->getCommandName()}

				## RESOURCES

				Service class will be created from this example:
				https://github.com/infinum/eightshift-libs/blob/develop/src/Manifest/ManifestExample.php
			"),
		];
	}

	/* @phpstan-ignore-next-line */
	public function __invoke(array $args, array $assocArgs)
	{
		$this->getIntroText($assocArgs);

		$className = $this->getClassShortName();

		// Read the template contents, and replace the placeholders with provided variables.
		$this->getExampleTemplate(__DIR__, $className)
			->renameClassName($className)
			->renameNamespace($assocArgs)
			->renameUse($assocArgs)
			->outputWrite(Components::getProjectPaths('srcDestination', 'Manifest'), "{$className}.php", $assocArgs);
	}
}
