<?php

/**
 * Class that registers WPCLI command for Load More route.
 *
 * @package EightshiftLibs\Rest\Routes\LoadMore
 */

declare(strict_types=1);

namespace OrderProtectionWpVendor\EightshiftLibs\Rest\Routes\LoadMore;

use OrderProtectionWpVendor\EightshiftLibs\Cli\AbstractCli;
use OrderProtectionWpVendor\EightshiftLibs\Cli\ParentGroups\CliCreate;
use OrderProtectionWpVendor\EightshiftLibs\Helpers\Components;

/**
 * Class LoadMoreRouteCli
 */
class LoadMoreRouteCli extends AbstractCli
{
	/**
	 * Get WPCLI command parent name
	 *
	 * @return string
	 */
	public function getCommandParentName(): string
	{
		return CliCreate::COMMAND_NAME;
	}

	/**
	 * Get WPCLI command name
	 *
	 * @return string
	 */
	public function getCommandName(): string
	{
		return 'rest-route-load-more';
	}

	/**
	 * Get WPCLI command doc
	 *
	 * @return array<string, array<int, array<string, bool|string>>|string>
	 */
	public function getDoc(): array
	{
		return [
			'shortdesc' => 'Create REST-API load more route class.',
			'longdesc' => $this->prepareLongDesc("
				## USAGE

				Used to create REST-API load more route, used in the blocks like featured-content.

				## EXAMPLES

				# Create service class:
				$ wp {$this->commandParentName} {$this->getCommandParentName()} {$this->getCommandName()}

				## RESOURCES

				Service class will be created from this example:
				https://github.com/infinum/eightshift-libs/blob/develop/src/Rest/Routes/LoadMore/LoadMoreRouteExample.php
			"),
		];
	}

	/* @phpstan-ignore-next-line */
	public function __invoke(array $args, array $assocArgs)
	{
		$sep = \DIRECTORY_SEPARATOR;
		$this->getIntroText($assocArgs);

		$className = $this->getClassShortName();

		// Read the template contents, and replace the placeholders with provided variables.
		$this->getExampleTemplate(__DIR__, $className)
			->renameClassName($className)
			->renameNamespace($assocArgs)
			->renameUse($assocArgs)
			->renameTextDomain($assocArgs)
			->outputWrite(Components::getProjectPaths('srcDestination', "Rest{$sep}Routes{$sep}LoadMore"), "{$className}.php", $assocArgs);
	}
}
